# coding=utf-8
# *** WARNING: this file was generated by Pulumi SDK Generator. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

from . import _utilities
import typing
# Export this package's modules as members:
from .attached_fargate_profile import *
from .attached_node_group import *
from .autoscaled_node_group import *
from .cluster import *
from .iam_role_mapping import *
from .iam_service_account_role import *
from .provider import *
from ._inputs import *
_utilities.register(
    resource_modules="""
[
 {
  "pkg": "lbrlabs-eks",
  "mod": "index",
  "fqn": "lbrlabs_pulumi_eks",
  "classes": {
   "lbrlabs-eks:index:AttachedFargateProfile": "AttachedFargateProfile",
   "lbrlabs-eks:index:AttachedNodeGroup": "AttachedNodeGroup",
   "lbrlabs-eks:index:AutoscaledNodeGroup": "AutoscaledNodeGroup",
   "lbrlabs-eks:index:Cluster": "Cluster",
   "lbrlabs-eks:index:IamRoleMapping": "IamRoleMapping",
   "lbrlabs-eks:index:IamServiceAccountRole": "IamServiceAccountRole"
  }
 }
]
""",
    resource_packages="""
[
 {
  "pkg": "lbrlabs-eks",
  "token": "pulumi:providers:lbrlabs-eks",
  "fqn": "lbrlabs_pulumi_eks",
  "class": "Provider"
 }
]
"""
)
